Conversation:
{recent_messages}

Insights:
{insights_text}

Reflection:
{reflection_text}

Semantic memory:
{semantic_text}

Deep memory:
{deep_text}

Existing:
{existing_intuitions}

Open tensions:
{open_tensions_text}

Maturing:
{maturing_text}

New intuitions JSON:
